package com.xy.service;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.github.yitter.idgen.YitIdHelper;
import com.xy.dto.DeviceAnnualFeeOrdersDto;
import com.xy.entity.DeviceAnnualFee;
import com.xy.entity.DeviceAnnualFeeOrders;
import com.xy.mapper.DeviceAnnualFeeOrdersMapper;
import com.xy.utils.Beans;
import com.xy.utils.DataTime;
import com.xy.utils.R;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;


/**
 * <p>
 * 设备年费订单表 服务实现类
 * </p>
 *
 * @author lijin
 * @since 2025-02-28
 */
@Service
@AllArgsConstructor
@Api(tags = "设备年费订单表")
public class DeviceAnnualFeeOrdersServiceImpl extends ServiceImpl<DeviceAnnualFeeOrdersMapper, DeviceAnnualFeeOrders> implements DeviceAnnualFeeOrdersService {

    private DeviceAnnualFeeServiceImpl deviceAnnualFeeService;

    @Override
    @ApiOperation("购买")
    public R pay(DeviceAnnualFeeOrdersDto.Pay pay) {
        LocalDateTime now = LocalDateTime.now();
        DeviceAnnualFeeOrders deviceAnnualFeeOrders = Beans.copy(DeviceAnnualFeeOrders.class, pay)
                .setId(YitIdHelper.nextId())
                .setCreateTime(now)
                .setUpdateTime(now);
        save(deviceAnnualFeeOrders);
        return R.ok();
    }

    @Override
    @ApiOperation("购买回调")
    public R payNotice(DeviceAnnualFeeOrdersDto.PayNotice payNotice) {
        DeviceAnnualFeeOrders deviceAnnualFeeOrders = getOne(new LambdaQueryWrapper<DeviceAnnualFeeOrders>()
                .eq(DeviceAnnualFeeOrders::getOrdersId, payNotice.getOrderId())
        );
        if (deviceAnnualFeeOrders == null) {
            return R.ok();
        }
        DeviceAnnualFee deviceAnnualFee = deviceAnnualFeeService.getOne(new LambdaQueryWrapper<DeviceAnnualFee>()
                .eq(DeviceAnnualFee::getMercId, deviceAnnualFeeOrders.getMercId())
                .eq(DeviceAnnualFee::getDeviceId, deviceAnnualFeeOrders.getDeviceId())
        );
        String timeout = DataTime.getStringAround(deviceAnnualFeeOrders.getSize(), 0, 0, 0, 0, 0, DataTime.toString(deviceAnnualFee.getTimeout()));
        deviceAnnualFee.setTimeout(DataTime.toLocal(timeout));
        deviceAnnualFeeService.updateById(deviceAnnualFee);
        deviceAnnualFeeOrders.setStatus(true).setUpdateTime(LocalDateTime.now());
        updateById(deviceAnnualFeeOrders);
        return R.ok();
    }
}